@@ -1,7 +1,7 @@
 ;;; gnus-async.el --- asynchronous support for Gnus
 ;; Copyright (C) 1996,97,98 Free Software Foundation, Inc.
 
-;; Author: Lars Magne Ingebrigtsen <larsi@ifi.uio.no>
+;; Author: Lars Magne Ingebrigtsen <larsi@gnus.org>
 ;; Keywords: news
 
 ;; This file is part of GNU Emacs.
@@ -213,11 +213,13 @@ It should return non-nil if the article is to be prefetched."
        (when arg
 	 (gnus-async-set-buffer)
 	 (gnus-async-with-semaphore
-	  (push (list ',(intern (format "%s-%d" group article)
-				gnus-asynch-obarray)
-		      ,mark (set-marker (make-marker) (point-max))
-		      ,group ,article)
-		gnus-async-article-alist)))
+	  (setq
+	   gnus-async-article-alist
+	   (cons (list ',(intern (format "%s-%d" group article)
+				 gnus-asynch-obarray)
+		       ,mark (set-marker (make-marker) (point-max))
+		       ,group ,article)
+		 gnus-async-article-alist))))
        (if (not (gnus-buffer-live-p ,summary))
 	   (gnus-async-with-semaphore
 	    (setq gnus-async-fetch-list nil))
